<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['upgrade_user'] = [
    [
        'version' => '0',
        'library' => 'user/migrations/user_upgrade_0',
    ],
    [
        'version' => '1.3.0',
        'library' => 'user/migrations/user_upgrade_1_3_0',
    ],
];
